/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog to input + - * / operations with constants or other listDataset
#include "FSOpDialog.h"
#include "FSDoubleValidator.h"

FSOpDialog::FSOpDialog(int op, FSDataSet *ffirstDataSet, QWidget *parent)
            : QDialog( parent )
{
    setupUi(this);

    firstDataSet = ffirstDataSet;
    if(op<-4 || (op<0 && firstDataSet==NULL) || op>4 || op==0) op=1;
    
    if(ffirstDataSet==NULL) listDataset->setEnabled( false );
    connect( rbConstant, SIGNAL(clicked()), SLOT(constantOp()) );
    connect( rbDataset, SIGNAL(clicked()), SLOT(datasetOp()) );

    switch(abs(op)) {
    case 1:
    default:
      rbPlus->setChecked(true);
      break;
    case 2:
      rbMinus->setChecked(true);
      break;
    case 3:
      rbTimes->setChecked(true);
      break;
    case 4:
      rbDivide->setChecked(true);
      break;
    }

    cbX->setChecked( false );
    cbY->setChecked( true );

    if (firstDataSet)
    {
        FSDataSet* pdataset = firstDataSet;
        while(pdataset)
        {
            listDataset->addItem( pdataset->legend );
            pdataset = pdataset->nextDataSet;
        }
        if(op<0)listDataset->setFocus();
    }
    else
        listDataset->setEnabled(false);

    if(op>0)
    {
        rbConstant->setChecked( true );
        constantOp();
    }
    else
    {
        rbDataset->setChecked( true );
        datasetOp();
    }

}

//
// return the operation number: 
//   with constant: 1 for +,  2 for -,  3 for *,  4 for /
//   with dataset: -1 for +, -2 for -, -3 for *, -4 for /
//
int FSOpDialog::operation( void )
{
    int op = 1;
    if(rbMinus->isChecked()) op=2;
    else if(rbTimes->isChecked()) op=3;
    else if(rbDivide->isChecked()) op=4;

    if(rbDataset->isChecked()) op = -op;

    return op;
}


// fills the array selectedlistDataset[] with pointers to selected listDataset 
// the element after the last is set to NULL
void FSOpDialog::selectedDatasets( FSDataSet* listlistDataset[] )
{
	int nselected = 0;
	listlistDataset[nselected] = NULL;

    if(rbDataset->isChecked())
    {
        FSDataSet *ds = firstDataSet;
        for(int i=0; i<int(listDataset->count()); i++)
        {
            if(listDataset->isItemSelected(listDataset->item(i))) {
				       listlistDataset[nselected++] = ds;
				       listlistDataset[nselected] = NULL;
            } 
            ds = ds->nextDataSet;
        }
    }
}


double FSOpDialog::constant( void )
{
    return constantEdit->text().toDouble();
}

bool FSOpDialog::onX( void )
{
    return cbX->isChecked();
}

bool FSOpDialog::onY( void )
{
    return cbY->isChecked();
}

void FSOpDialog::constantOp( void )
{
    gbConstant->setEnabled(true);
    constantEdit->setEnabled(true);
    constantEdit->focusWidget();
    cbX->setEnabled(true);
    cbY->setEnabled(true);

    gbDataSet->setEnabled(false);
    listDataset->setEnabled(false);
}

void FSOpDialog::datasetOp( void )
{
    gbConstant->setEnabled(false);
    constantEdit->setEnabled(false);
    cbX->setEnabled(false);
    cbY->setEnabled(false);

    gbDataSet->setEnabled(true);
    listDataset->setEnabled(true);
}
