#include <QApplication>
#include <QSplashScreen>
#include <QString>
#include <QCoreApplication>
#include <QDir>
#include <QFile>
#include <QMessageBox>

#include "CorteoUi.h"

int main(int argc, char *argv[])
{

  #if defined(Q_OS_MAC)
  {
     // we need to do this in order to have the app referenced to libqcocoa bundeled with CorteoUi.app
     QDir dir(argv[0]);  // ./CorteoUi.app/Contents/MacOS/appname
     dir.cdUp();
     dir.cdUp();
     dir.cd("PlugIns");   // ./CorteoUi.app/Contents/PlugIns
     QCoreApplication::setLibraryPaths(QStringList(dir.absolutePath()));
  }
  #endif

  QApplication app(argc, argv);
  Q_INIT_RESOURCE(CorteoUi);


  // set current dir to the directory of the application
  QDir dir(QCoreApplication::applicationDirPath());
  #if defined(Q_OS_WIN)
  if (dir.dirName().toLower() == "debug" ||
      dir.dirName().toLower() == "release")
  {
      dir.cdUp();
  }
  #elif defined(Q_OS_MAC)
  if (dir.dirName() == "MacOS")
  {
      dir.cdUp();
      dir.cdUp();
      dir.cdUp();
  }
  #endif
  QDir::setCurrent(dir.absolutePath());

  if(!QFile::exists("corteo.agreement")) {
      if(QMessageBox::question(NULL, "Corteo user interface: agreement",
                            "I understand that Corteo is distributed under the terms of the GNU General Public Licence 3.0 (see file LICENCE.txt)\n\n"
                            "I understand that Corteo contains and uses stopping power tables generated using SRIM (www.srim.org).")
              == QMessageBox::Yes) {
          QFile file("corteo.agreement");
          if( file.open(QIODevice::WriteOnly| QIODevice::Text) ) {
              file.write("The user understands that Corteo is distributed under the terms of the GNU General Public Licence 3.0\n"
                         "and that it contains and uses stopping power tables generated using SRIM.");
              file.close();
          } else {
              return 2;
          }
      } else {
          return 2;
      }
  }

  // splash screeen
  QSplashScreen * splash = new QSplashScreen(QPixmap(":/images/splash.png")); // from resources
  splash->show();

  int numberLayer = 5;
  int numberElement = 5;

  if(argc>=2 && argc<=3) {

    // first argument is the number of layers
    bool ok;
    QString str = QString(argv[1]);

    // convert it to int and check if conversion was ok
    int val = str.toInt(&ok);
    if(ok && val>0) numberLayer = val;

    if(argc==3) {
      // second argument is the number of element in each layer
      str = QString(argv[2]);

      // convert it to int and check if conversion was ok
      val = str.toInt(&ok);
      if(ok && val>0) numberElement = val;
    }
  }


  // create and show CorteuUi
  CorteoUi * corteoUi = new CorteoUi(NULL, numberLayer, numberElement, splash);
  corteoUi->show();

  // delete splash screen
  splash->finish(corteoUi);
  delete splash;

  // run corteoUi
  return app.exec();
}
