/*
    Copyright 2007, Francois Schiettekatte

    This file is part of Corteo.

    Corteo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Corteo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Corteo.  If not, see <http://www.gnu.org/licenses/>.

*/

#include <stdio.h>
#include <string.h>
#include "corteodedx.h"
#include "corteomatrix.h"

// generate matrix and stopping power tables (long...)
int main(int argc, char *argv[]){
    int j, done = 0;

    if (argc == 2) {
        if(strcmp(argv[1],"stopping")==0 || strcmp(argv[1],"everything")==0 ) {
             generateDedxTables();
             done = 1;
        }
        if(strcmp(argv[1],"screening")==0 || strcmp(argv[1],"everything")==0 ) {
            for(j=0;j<=3;j++)
                if(j!=ANDERSEN)
                    calcMatrix(j,1);
            done = 1;
        }
        if(strcmp(argv[1],"screening=None")==0) {
            calcMatrix(NOSCREEN,1);
            done = 1;
        }
        if(strcmp(argv[1],"screening=Universal")==0) {
            calcMatrix(UNIVERSAL,1);
            done = 1;
        }
        if(strcmp(argv[1],"screening=LenzJensen")==0) {
            calcMatrix(LENZJENSEN,1);
            done = 1;
        }
    }

    if(done)
        return 0;

    printf("Usage: \"%s \" followed by one of the following\n"
           "  \"everything\": stopping + screening\n"
           "  \"stopping\": compute stopping tables using SRIM SRModule (see instructions)\n"
           "  \"screening\": compute and store scattering and cross-section matrices for all three screening functions below\n"
           "  \"screening=None\": compute only the matrices with no screening (Coulomb potential)\n"
           "  \"screening=Universal\": compute only the matrices for Universal screening function\n"
           "  \"screening=LenzJensen\": compute only the matrices for Lenz-Jensen screening function\n", argv[0]);

    return 1;
}
